# Calculation method

- [Initial position estimation](#initial-positions)
- [Calculation of geometric distances](#distances)
- [Estimation of landing gear loads](#loads)
- [Tire selection](#tires)
- [Limitation check](#limitations)
- [Clearance compliance check](#clearances)
- [Estimation of landing gear mass](#mass)
- [Estimation of aircraft classification number](#acn)


## Initial positions {#initial-positions}
First, initial x axis positions for the nose $x_{\text{NLG}}$ and main landing gear $x_{\text{MLG}}$ are estimated. If any of the required values are missing, default values are used, such as a minimum distance of 2 meters between the main landing gear and the aft-most center of gravity.

The nose gear position is determined either from module configuration data or input parameters, such as the front reference point of the payload area or existing landing gear positions. If no relevant data is available, a default starting position, such as 5 meters, is applied.

Similarly, the main landing gear position is estimated. Depending on the aircraft type, default positions of 19 meters (single-aisle) and 32 meters (wide-body) are assigned. Additional factors, including wing reference points, center of gravity data, and wing chord lengths, are incorporated into the estimation if available. A temporary center of gravity is also calculated based on the main landing gear position and the safety margin from the aft-most center of gravity.

These positions are recalculated on an ongoing basis.

## Distances {#distances}
Afterwards, critical distances (lever arms) and tipping points for estimating loads on the landing gear are calculated.
Default values are assigned if parameters are not explicitly provided.

### Horizontal distances
![](figures/horizontal_distances.png)

#### Distance between nose and main landing gear
The distance between the nose and the main landing gear can be estimated using the following equation:
$$
  d_{\text{NLG-MLG}} = |x_{\text{MLG}} - x_{\text{NLG}}|
$$

In which

- $x_{\text{MLG}}$ - x position of main landing gear
- $x_{\text{NLG}}$ - x position of nose landing gear

#### Distance between nose gear and foremost center of gravity position
If the foremost center of gravity position is already known, the distance to the nose gear can be determined according to the following formula:
$$
  d_{\text{NLG front CG}} = |x_{\text{front CG}} - x_{\text{NLG}}|
$$

In which

- $x_{\text{front CG}}$ - x position of foremost center of gravity

Otherwise, $d_{\text{NLG front CG}}$ is determined by using a first estimation:
$$
  d_{\text{NLG front CG}} = |(x_{\text{MLG}} - 2) - x_{\text{NLG}}|
$$

#### Distance between nose gear and rearmost center of gravity
The distance between the nose gear position and the rearmost center of gravity in x direction can be calculated as follows:
$$
  d_{\text{NLG rear CG}} = |x_{\text{rear CG}} - x_{\text{NLG}}|
$$

In which

- $x_{\text{rear CG}}$ - x position of rearmost center of gravity

Otherwise, $d_{\text{NLG rear CG}}$ is determined by using a first estimation:
$$
  d_{\text{NLG rear CG}} = |(x_{\text{MLG}} - 1) - x_{\text{NLG}}|
$$

#### Distance between main landing gear and rearmost center of gravity position
If no distance between the main landing gear and the rearmost center of gravity is available from earlier iterations, it equals `1.0`.

### Vertical distances
![](figures/vertical_distances.png)

#### Vertical distance between ground and center of gravity position
Starting with the second iteration loop, the vertical distance between ground and center of gravity $\Delta h_{\text{GND-CG}}$ is known.

In the first loop, however, the vertical distance must be calculated as sum of the following heights:

1. Vertical distance from fuselage center line to center of gravity $\Delta h_{\text{FCL-CG}}$
2. z position of tail tipping point (equals vertical distance between fuselage center line and tail tipping point) $z_{\text{TP}}$
3. Vertical distance from tail tipping point to ground $\Delta h_{\text{TP-GND}}$

**1. Vertical distance from fuselage center line to center of gravity**<br>
The distance between global center of gravity in z-direction and the fuselage center line $\Delta h_{\text{FCL-CG}}$ is either estimated by subtracting the z position of the fuselage center line $z_{\text{FCL}}$ from the z position of the most aft CG position $z_{\text{rear CG}}$
$$
  \Delta h_{\text{FCL-CG}} = |z_{\text{rear CG}} - z_{\text{FCL}}|
$$

or, if those values are not given, set to `0.5` for single-aisle and `1.0` for wide-body configurations.

**2. z position of tail tipping point**<br>
If the position of the tail tipping point in z direction is not known, it is assumed to equal $z_{\text{TP}} = -0.3 \cdot h_{\text{fuselage}}$. The fuselage height $h_{\text{fuselage}}$ in meter is known or assumed to be `3.8` for single-aisle and `5.8` for wide-body aircraft.

**3. Vertical distance from tail tipping point to ground**<br>
The vertical distance from the tail tipping point to the ground $\Delta h_{\text{TP-GND}}$ is estimated in the following way:

$$
  \Delta h_{\text{TP-GND}} = |\tan(\theta_{\text{LDG}}) \cdot d_{\text{MLG-TP}}| - h_{\text{susp}}
$$

The vertical distance between the main landing gear and the tail tipping point $d_{\text{MLG-TP}}$ is either known or set to `15.0` for single-aisle or `25.0` for wide-body aircraft configurations.

If a strut suspension system is implemented, the vertical distance between ground and CG decreases by the suspension travel $h_{\text{susp}}$ that equals `0.0` if no suspension system is implemented.

**Vertical distance between ground and center of gravity position**<br>
Finally, the vertical distance between the ground and the CG position can be calculated by summing up these values:
$
  \Delta h_{\text{GND-CG}} = \Delta h_{\text{FCL-CG}} + |z_{\text{TP}}| + \Delta h_{\text{TP-GND}}
$

## Load estimation {#loads}
Subsequently, the loads on the nose and main landing gear are calculated based on Norman S. Currey's work<sup>[1]</sup>, unless explicitly stated otherwise. It considers the static and dynamic loads during takeoff, landing, and taxiing, while ensuring the loads conform to the permissible percentages as per aviation regulations.

The following data is necessary:

- Maximum aft position of nose landing gear
- Minimum foremost position of nose landing gear
- Minimum foremost position of main landing gear
- Maximum ramp weight

If no values are available, initial values are set.

### Nose landing gear loads
**Minimum static nose gear load**
$$
  L_{\text{NLG,stat,min}} = \frac{MRW \cdot (d_{\text{NLG-MLG}} - d_{\text{NLG rear CG}})}{d_{\text{NLG-MLG}}}
$$

In which

- $MRW$ - maximum ramp weight
- $d_{\text{NLG-MLG}}$ - distance between nose and main gear
- $d_{\text{NLG rear CG}}$ - distance between nose gear and rearmost center of gravity

**Maximum static nose gear load**
$$
  L_{\text{NLG,stat,max}} = \frac{MRW \cdot (d_{\text{NLG-MLG}} - d_{\text{NLG front CG}})}{d_{\text{NLG-MLG}}}
$$

In which

- $MRW$ - maximum ramp weight
- $d_{\text{NLG-MLG}}$ - distance between nose and main gear
- $d_{\text{NLG front CG}}$ - distance between nose gear and foremost center of gravity

**Maximum dynamic nose gear load**
$$
  L_{\text{NLG,dyn,max}} = L_{\text{NLG,stat,max}} + \frac{10 \cdot d_{\text{GND rear CG}} \cdot MRW}{32.2 \cdot d_{\text{NLG-MLG}}}
$$

In which

- $d_{\text{GND rear CG}}$ - vertical distance between ground and aft center of gravity

The static loads on the nose landing gear should be between 6% and 20% of the maximum ramp weight for all CG positions. These values are absolute limits and must not be exceeded at any time. Ideally, the static loads for the minimum and maximum nose landing gear load should be between 8% and 15%. If the limits are violated, the landing gear positions and/or the empty mass center of gravity must be varied. This leads to a renewed check of the center of gravity movement and the limits to be adhered to (iterative process).

#### Dynamic nose gear loads for takeoff and landing condition
The calculation of the dynamic nose gear loads for takeoff and landing conditions is in accordance with CS 25.733 (b)(2) and (b)(3)<sup>[2]</sup>.

**Maximum static nose gear landing load**<br>
In order to calculate the maximum static nose gear load at landing, the maximum static nose gear landing load $ L_{\text{NLG,stat,max,LDG}}$ has to be estimated first.

$$
  L_{\text{NLG,stat,max,LDG}} = \frac{MLM \cdot g \cdot (d_{\text{NLG-MLG}} - d_{\text{NLG front CG}})}{d_{\text{NLG-MLG}}}
$$

In which

- $MLM$ - maximum landing mass
- $ g$ - gravitational acceleration
- $d_{\text{NLG-MLG}}$ - distance between nose and main gear
- $d_{\text{NLG front CG}}$ - distance between nose gear and foremost center of gravity

!!! note
    If no maximum landing mass exists, 90% of the maximum ramp weight are initially assumed for the calculation.

Subsequently, the maximum dynamic load at landing $ L_{\text{NLG,dyn,max,LDG}} $ can be calculated based on CS 25.733 (b)(2):
$$
  L_{\text{NLG,dyn,max,LDG}} = L_{\text{NLG,stat,max,LDG}} + 0.31 \cdot L_{\text{NLG,stat,max,LDG}}
$$

**Maximum dynamic nose gear takeoff load**<br>
The maximum dynamic nose gear load at takeoff can be calculated in accordance with CS 52.733 (b)(3):
$$
  L_{\text{NLG,dyn,max,TO}} = L_{\text{NLG,stat,max}} + 0.2 \cdot L_{\text{NLG,stat,max}}
$$

### Main landing gear loads
The total main gear load can be estimated using the following equation:
$$
  L_{\text{MLG,max}} = \frac{100 - L_{\text{NLG,stat,min}}}{100} \cdot MRW
$$

In which

- $L_{\text{NLG,stat,min}}$ - minimum static nose gear load **in percent**

### Nose landing gear position
The maximum possible foremost and aft position of the nose landing gear can be determined based on the loads.

#### Foremost nose landing gear position
A maximum of 20 percent of the maximum ramp weight is allowed as the maximum static nose gear load $L_{\text{NLG,stat,max,possible}}$:
$$
  L_{\text{NLG,stat,max,possible}} = 0.06 \cdot MRW
$$

The foremost nose landing gear position therefore results in:
$$
  d_{\text{NLG front CG min}} = \frac{MRW \cdot d_{\text{NLG-MLG}} - L_{\text{NLG,stat,max,possible}} \cdot d_{\text{NLG-MLG}}}{MRW}
$$

In which

- $MRW$ - maximum ramp weight
- $d_{\text{NLG-MLG}}$ - distance between nose and main gear

#### Aft nose landing gear position
A minimum of 6 percent of the maximum ramp weight is allowed as the minimum static nose gear load $L_{\text{NLG,stat,min,possible}}$:
$$
  L_{\text{NLG,stat,min,possible}} = 0.2 \cdot MRW
$$

The aft nose landing gear position therefore results in:
$$
  d_{\text{NLG aft CG max}} = \frac{MRW \cdot d_{\text{NLG-MLG}} - L_{\text{NLG,stat,min,possible}} \cdot d_{\text{NLG-MLG}}}{MRW}
$$

## Tires {#tires}
Tire selection in accordance to CS 25.733<sup>[2]</sup> und EASA ETSO tire list<sup>[3]</sup>, bridgestone aircraft tires<sup>[4]</sup>  from landing gear lib (see [getting started](getting_started.md) page for more information).
 
If a maximum takeoff stall speed exists, the maximum design speed **(in miles per hour)** corresponds to the greater of the two values maximum approach speed or maximum takeoff stall speed*1.3:
$$
  v_{\text{max,des}} = max(v_{\text{app,max}},v_{\text{s,TO}} \cdot 1.3)
$$

In which

- $v_{\text{app,max}}$ - maximum approach speed (in mph)
- $v_{\text{s,TO}}$ - takeoff stall speed (in mph)

Otherwise, the following applies:
$$
  v_{\text{max,des}} = v_{\text{app,max}}
$$

### Nose gear
For both, the number of nose gear struts $n_{\text{NLG struts}}$ as well as the number of nose gear tires per strut $n_{\text{NLG tires per strut}}$, the user can define specific values. These values are checked for compliance and parameters, e.g., the number of axis, are set accordingly. If no values are given, default values are used.

#### Design load estimation
The **single tire design load** $v_{\text{NLG,tire,des}}$ is calculated according to CS 25.733 (b)(1):
$$
  v_{\text{NLG,tire,des}} = \frac{\frac{L_{\text{NLG,stat,max}}}{g} \cdot 2.2}{n_{\text{NLG tires per strut}} \cdot n_{\text{NLG struts}}}
$$

In which

- $L_{\text{NLG,stat,max}}$ - maximum static nose gear load
- $g$ - gravitational acceleration

Subsequently, the **single tire dynamic landing load** $v_{\text{NLG tire LDG}}$ is estimated based on CS 25.733 (b)(2):
$$
  v_{\text{NLG tire LDG}} = \frac{\frac{L_{\text{NLG,dyn,max,LDG}}}{g} \cdot 2.2}{n_{\text{NLG tires per strut}} \cdot n_{\text{NLG struts}}}
$$

In which

- $L_{\text{NLG,dyn,max,LDG}}$ - maximum dynamic load at landing

Afterwards, the calculation of the **single tire dynamic takeoff load** $v_{\text{NLG tire TO}}$ for nose gear tires is in accordance to CS 25.733 (b)(3):
$$
  v_{\text{NLG tire TO}} = \frac{\frac{L_{\text{NLG,dyn,max,TO}}}{g} \cdot 2.2}{n_{\text{NLG tires per strut}} \cdot n_{\text{NLG struts}}}
$$

In which

- $L_{\text{NLG,dyn,max,TO}}$ - maximum dynamic load at takeoff

#### Tire selection
Knowing the design speed and loads, a suitable tire is selected from the database.

### Main gear tire selection
Similar to the nose landing gear, the number of main gear struts $n_{\text{MLG struts}}$ as well as the number of main gear tires per strut $n_{\text{MLG tires per strut}}$ can be defined by the user. These values are checked for compliance and parameters, e.g., the number of axis, are set accordingly. If no values are given, default values are used.

#### Design load estimation
The **single tire design load** is calculated according to CS 25.733 (a)(1):
$$
  v_{\text{MLG tire des}} = \frac{\frac{L_{\text{MLG,max}}}{g} \cdot 2.2}{n_{\text{MLG tires per outer strut}} \cdot n_{\text{MLG outer struts}} + n_{\text{MLG tires per inner strut}} \cdot n_{\text{MLG inner struts}}} \cdot f_{\text{safety}}
$$

In which

- $L_{\text{MLG,max}}$ - maximum main gear load
- $g$ - gravitational acceleration
- $n_{\text{MLG tires per outer strut}}$ - number of tires per outer strut
- $n_{\text{MLG outer struts}}$ - number of outer struts
- $n_{\text{MLG tires per inner strut}}$ - number of tires per inner strut
- $n_{\text{MLG inner struts}}$ - number of inner struts
- $f_{\text{safety}}$ - safety factor

If only one main gear tyre is mounted to one main landing gear strut, $f_{\text{safety}} = 1$. If more than one tire is mounted to one main landing gear strut, an additional safety load margin according to CS 25.733 (c)(1) is required that results in $f_{\text{safety}} = 1.07$.

#### Tire selection
Knowing the design speed and loads, a suitable tire is selected from the database.

## Limitations {#limitations}
Estimation of ground strike limitations in accordance to Sforza<sup>[5]</sup> and CS-25<sup>[2]</sup>.

The safest and highest permissible rotation angle during takeoff, considering both landing constraints and tail tipping risks, is calculated, considering different constraints and configurations.

**Maximum Rotation Angle for Landing**<br>
If the maximum angle of attack during landing is provided, it is compared to the defined tail strike limit and the greater of the two is selected.
If this value is not provided, it defaults to using only the given tail strike limit.

**Maximum Tail Tipping Angle**<br>
The calculated maximum rotation angle at landing is compared with the maximum rotation angle during takeoff. The larger of these values is taken as the maximum tail tipping angle.

With the known values, the landing gear placement and dimensions are estimated meeting constraints like stability, retractability, turnover limits, and tail strike prevention. If the criteria aren't met, the design is refined in an iterative process.

## Clearances {#clearances}
Ground clearance angles for nacelles and wing tips are calculated and verified in accordance to Torenbeek<sup>[6]</sup> and CS-25<sup>[2]</sup>.

### Nacelle clearance
The ground clearance $c_{\text{nacelle}}$ for each nacelle is given as:
$$
  c_{\text{nacelle}} = d_{\text{GND to FCL}} - |z_{\text{nacelle}}| - |h_{\text{nacelle}}|
$$

In which

- $d_{\text{GND to FCL}}$ - vertical distance between ground and fuselage center line
- $z_{\text{nacelle}}$ - z position of nacelle
- $h_{\text{nacelle}}$ - height of nacelle

The nacelle clearance angle can then be determined:
$$
  \theta_{\text{nacelle}} = \arctan\left(\frac{c_{\text{nacelle}}}{|y_{\text{nacelle}}| - y_{\text{MLG outer strut}}}\right) \cdot \frac{180}{\pi}
$$

In which:

- $y_{\text{nacelle}}$ - y position of nacelle
- $y_{\text{MLG outer strut}}$ - y position of outer main landing gear strut

This value is then checked regarding the minimum required clearance angle of 5 degree, defined by CS 25.149, and the user-specified nacelle clearance angle.

### Wing tip clearance
The wing tip ground clearance $c_{\text{wing tip}}$ is known from the positions of the wing tip section.
$$
  c_{\text{wing tip}} = d_{\text{GND to FCL}} - z_{\text{wing tip}}
$$

In which

- $d_{\text{GND to FCL}}$ - vertical distance between ground and fuselage center line
- $z_{\text{wing tip}}$ - z position of wing tip

The wing tip clearance angle is calculated using the wing tip's position relative to the main gear outer strut:
$$
    \theta_{\text{wing tip}} = \arctan\left(\frac{c_{\text{wing tip}}}{|y_{\text{wing tip}}| - y_{\text{MLG outer strut}}}\right) \cdot \frac{180}{\pi}
$$

In which:

- $y_{\text{wing tip}}$ - y position of wing tip
- $y_{\text{MLG outer strut}}$ - y position of outer main landing gear strut

This value is then validated against the minimum required clearance angle of 5 degree, defined by CS 25.149, and the user-specified wing tip clearance angle.

## Masses {#mass}
The undercarriage masses are calculated in accordance to Torenbeek<sup>[6]</sup> using the following coefficients (taken from Table 8-6):

| Gear Type      | Position | A       | B       | C       | D           |
|----------------|----------|---------|---------|---------|-------------|
| Fixed          | Main     | 9.1     | 0.082   | 0.019   | 0           |
| Fixed          | Nose     | 11.3    | 0       | 0.0024  | 0           |
| Retractable    | Main     | 18.1    | 0.131   | 0.019   | 0.0000223   |
| Retractable    | Nose     | 9.1     | 0.082   | 0       | 0.00000297  |

Under the use of these coefficients, the mass for the nose as well as the main landing gear can be calculated using the following equation:

$$
  m = c_{\text{wing}} \cdot \left( A + B \cdot MTOM^{0.75} + C \cdot MTOM + D \cdot MTOM^{1.5} \right) \cdot f_{\text{corr}}
$$

In which:

- $c_{\text{wing}}$ - wing position coefficient (`1.0`for low or mid wing position, `1.8`for high wing position)
- $MTOM$ - maximum takeoff mass
- $f_{\text{corr}}$ - landing gear correction factor (taken from user specification)
- $ A,B,C,D$ - coefficients from above table

!!! note 
    If the maximum takeoff mass is not available, it is calculated by dividing the maximum ramp weight by the gravitational acceleration.

The total nose/main landing gear mass divided by the number of struts per nose/main landing gear results in the per-strut mass.

## Aircraft classification number {#acn}
The calculation is based on the COMFAA Tool developed by the Federal Aviation Administration (FAA) that is specifically used for computing the ACN (Aircraft Classification Number) in line with ICAO standards.
Detailed information can be taken from the website:

!!! note 
    By clicking on the following link, you will leave the UNICADO website. Please note that we are not responsible for the content of the linked website and do not assume any liability.<br>
    [External link to FAA COMFAA 3.0](https://www.airporttech.tc.faa.gov/Products/Airport-Safety-Papers-Publications/Airport-Safety-Detail/comfaa-30)

The Aircraft Classification Number (ACN) is a standardized measure that describes the load a particular aircraft imposes on the surface of a runway or taxiway. It is defined by the International Civil Aviation Organization (ICAO) in Annex 14<sup>[7]</sup> and is used to assess whether an aircraft is compatible with a specific pavement's structural capacity, expressed as the Pavement Classification Number (PCN).
The subsequent section provides some information on the method.

### Key characteristics of ACN
1. Definition
  - The ACN represents the relative structural impact of an aircraft on a pavement.
  - It is calculated based on the aircraft's weight, landing gear configuration, wheel spacing, and maximum takeoff weight.
2. Calculation
  - The ACN is determined for two types of pavements:
    - Rigid pavements: Concrete surfaces with a stiff structure.
    - Flexible pavements: Asphalt or other elastic materials.
    !!! note 
        Currently only flexible pavement implemented. 
  - Subgrade strength (the strength of the ground beneath the pavement) is divided into four categories: High (H), Medium (M), Low (L), Very Low (VL).
3. Standardization
  - The ACN is normalized to a reference Single Wheel Load (SWL) of 10 tons.
  - As a result, it is independent of specific airport conditions.
4. Comparison
  - The ACN of an aircraft is compared to the PCN of a pavement:
    - ACN ≤ PCN: The aircraft can use the pavement without causing damage.
    - ACN > PCN: Using the pavement may lead to structural damage and is generally restricted.

### Factors influencing ACN
- **Aircraft weight:** Heavier aircraft have higher ACNs.
- **Landing gear configuration:** Aircraft with more wheels or better weight distribution have lower ACNs.
- **Wheel spacing:** Wider spacing reduces the load concentration and lowers the ACN.
- **Pavement type:** The ACN for rigid and flexible pavements differs for the same aircraft.

___

<sup>[1]</sup> N. S. Currey. *Aircraft Landing Gear Design: Principles and Practices*. Washington DC: American Institute of Aeronautics und Astronautics, 1988.<br>
<sup>[2]</sup> European Union Aviation Safety Agency (EASA). *Certification Specifications and Acceptable Means of Compliance for Large Aeroplanes (CS-25). Amendment 27*. 2021.<br>
<sup>[3]</sup> European Union Aviation Safety Agency (EASA). *List of ETSO Authorisations*. 2022.<br>
<sup>[4]</sup> Bridgestone. *Aircraft Tires*. Online. URL: https://www.bridgestone.com/products/aircraft/products/applications/.<br>
<sup>[5]</sup> P. Sforza. *Commercial Airplane Design Principles*. Elsevier Inc., 2014.<br>
<sup>[6]</sup> E. Torenbeek, 1982. *Synthesis of Subsonic Airplane Design*.<br>
<sup>[7]</sup> ICAO, 2022. *ICAO Annex 14, Aerodromes, Volume I - Aerodrome Design and Operations*.<br>