# Design your first landing gear
Let's dive into the fun part and design a landing gear!

## Tool single execution
The tool can be executed from the console directly if all paths are set. The following will happen:

- [Console output](#console-output)
- [Generation of reports and plots](#reporting)
- [Writing output to aircraft exchange file](#acxml)
- [Generation of geometry file](#existing-geometry-file)

Some of the above mentioned steps did not work? Check out the [troubleshooting](#troubleshooting) section for advices.
Also, if you need some additional information on the underlying methodology, check out the page on the [landing gear design method](design_method.md).

So, feel free to open the terminal and run `landing_gear_design.exe` to see what happens...

### Console output {#console-output}
Firstly, you see output in the console window. Let's go through it step by step...

```
2024-11-11 17:36:51,541 - PRINT - Landing gear design started...
2024-11-11 17:36:51,614 - PRINT - Current run of landing gear iteration is: 1
```
To this point, the module started and printed the iteration counter.

```
2024-11-11 17:36:51,626 - WARNING - Attention: No engines available in the aircraft exchange file, nacelle ground clearance could not be checked!
2024-11-11 17:36:51,626 - PRINT - The resulting wing tip angle conforms the specified clearance angle of: 8.0 degrees!
2024-11-11 17:36:51,627 - PRINT - Total mass of landing gear is: 2558.0104kg!
```
Subsequently, some restrictions that must be met are checked and the mass of the landing gear ist calculated.

```
2024-11-11 17:36:51,627 - PRINT - ----- Nose gear results of current loop -----
2024-11-11 17:36:51,627 - PRINT - Nose gear x-position is: 5.75 meter behind reference point.
2024-11-11 17:36:51,628 - PRINT - Nose gear y-position is: 0.0 meter from reference center line.
2024-11-11 17:36:51,628 - PRINT - Nose gear z-position is: -1.4712 meter below reference center line.
2024-11-11 17:36:51,628 - PRINT - Number of nose gear struts is: 1.
2024-11-11 17:36:51,629 - PRINT - Nose gear strut length is: 0.8264 meter.
2024-11-11 17:36:51,629 - PRINT - Number of nose gear axis per strut is: 1.
2024-11-11 17:36:51,629 - PRINT - Number of nose gear tires per strut is: 2.
2024-11-11 17:36:51,629 - PRINT - Nose gear tires design load is: 8771.8989 pound.
2024-11-11 17:36:51,629 - PRINT - Selected nose gear tire type is: APS01203.
2024-11-11 17:36:51,630 - PRINT - ----- Main gear results of current loop -----
2024-11-11 17:36:51,630 - PRINT - Outer main gear x-position is: 22.4023 meter behind reference point.
2024-11-11 17:36:51,630 - PRINT - Outer main gear strut y-position is: 2.961 meter from reference center line.
2024-11-11 17:36:51,630 - PRINT - Outer main gear strut z-position is: -0.9536 meter below reference center line.
2024-11-11 17:36:51,630 - PRINT - Number of outer main gear struts is: 2.
2024-11-11 17:36:51,631 - PRINT - Outer main gear strut length is: 1.344 meter.
2024-11-11 17:36:51,631 - PRINT - Number of main gear axis per outer strut is: 1.
2024-11-11 17:36:51,631 - PRINT - Number of main gear tires per outer strut is: 2.
2024-11-11 17:36:51,631 - PRINT - Main gear tires design load is: 36727.855 pound.
2024-11-11 17:36:51,631 - PRINT - Selected main gear tire type is: APS01347-A.
```
Afterwards, the calculation results of the nose and main gear are printed.

As the landing gear design is an integrative process, several runs may be required to achieve a valid design. Each run generates log file entries similar to those just explained. In the present example, 5 runs are needed. For the sake of clarity, the results of the fifth run are shown before the final messages are explained.

```
2024-11-11 17:36:51,644 - PRINT - Current run of landing gear iteration is: 5
2024-11-11 17:36:51,645 - WARNING - Attention: No engines available in the aircraft exchange file, nacelle ground clearance could not be checked!
2024-11-11 17:36:51,645 - PRINT - The resulting wing tip angle conforms the specified clearance angle of: 8.0 degrees!
2024-11-11 17:36:51,645 - PRINT - Total mass of landing gear is: 2558.0104kg!
2024-11-11 17:36:51,646 - PRINT - ----- Nose gear results of current loop -----
2024-11-11 17:36:51,646 - PRINT - Nose gear x-position is: 5.75 meter behind reference point.
2024-11-11 17:36:51,646 - PRINT - Nose gear y-position is: 0.0 meter from reference center line.
2024-11-11 17:36:51,646 - PRINT - Nose gear z-position is: -1.4712 meter below reference center line.
2024-11-11 17:36:51,646 - PRINT - Number of nose gear struts is: 1.
2024-11-11 17:36:51,646 - PRINT - Nose gear strut length is: 1.4339 meter.
2024-11-11 17:36:51,647 - PRINT - Number of nose gear axis per strut is: 1.
2024-11-11 17:36:51,647 - PRINT - Number of nose gear tires per strut is: 2.
2024-11-11 17:36:51,647 - PRINT - Nose gear tires design load is: 9295.5602 pound.
2024-11-11 17:36:51,647 - PRINT - Selected nose gear tire type is: APS01203.
2024-11-11 17:36:51,647 - PRINT - ----- Main gear results of current loop -----
2024-11-11 17:36:51,647 - PRINT - Outer main gear x-position is: 21.465 meter behind reference point.
2024-11-11 17:36:51,647 - PRINT - Outer main gear strut y-position is: 3.6161 meter from reference center line.
2024-11-11 17:36:51,647 - PRINT - Outer main gear strut z-position is: -0.906 meter below reference center line.
2024-11-11 17:36:51,647 - PRINT - Number of outer main gear struts is: 2.
2024-11-11 17:36:51,648 - PRINT - Outer main gear strut length is: 1.9991 meter.
2024-11-11 17:36:51,648 - PRINT - Number of main gear axis per outer strut is: 1.
2024-11-11 17:36:51,648 - PRINT - Number of main gear tires per outer strut is: 2.
2024-11-11 17:36:51,648 - PRINT - Main gear tires design load is: 36587.776 pound.
2024-11-11 17:36:51,648 - PRINT - Selected main gear tire type is: APS01347-A.
```

```
2024-11-11 17:36:51,648 - PRINT - Landing gear design successful after 5 iterations!
2024-11-11 17:36:51,740 - PRINT - ACN for CBR =  3 (ultra-low) is: 44.2
2024-11-11 17:36:51,740 - PRINT - ACN for CBR =  6 (low) is:       38.6
2024-11-11 17:36:51,740 - PRINT - ACN for CBR = 10 (medium) is:    35.3
2024-11-11 17:36:51,740 - PRINT - ACN for CBR = 15 (high) is:      34.0
2024-11-11 17:36:53,410 - PRINT - Plots for landing gear design are successfully generated and saved.
2024-11-11 17:36:53,410 - PRINT - Moin! This is the "method_html_report" function from the landing_gear_design tool speaking... [Imagine fancy reports are generated here (you can find me in the "methodhtmlreport.py" file).]
2024-11-11 17:36:53,413 - PRINT - Method-specific data are written to 'landing_gear_design_results.xml'...
2024-11-11 17:36:53,418 - PRINT - Moin! This is the "method_tex_output" function from the landing_gear_design tool speaking... [Imagine fancy reports are generated here (you can find me in the "methodtexoutput.py" file).]
2024-11-11 17:36:53,418 - PRINT - Landing gear design finished.
```
Finally, you receive information about the reports and plots created (depending on your settings) and the tool is successfully completed.

### Reporting {#reporting}
In the following, a short overview is given on the generated reports:

- A `landing_gear_design.log` file is written within the directory of the executable
- Depending on your settings, the following output is generated and saved in the `reporting` folder, located in the directory of the aircraft exchange file:
    - an HTML report in the `report_html` folder
    - a TeX report in the `report_tex` folder (not implemented yet)
    - an XML file with additional output data in the `report_xml` folder
    - plots in the `plots` folder

### Write data to the aircraft exchange file {#acxml}
!!! note 
    The _acXML_ is an exchange file - we agreed on that only data will be saved as output that is needed by another tool!

Results are saved in the aircraft exchange file at the `/aircraft_exchange_file/component_design/landing_gear` node. The following information is written to the _acXML_:
```plaintext
Aircraft exchange file
|- Component design
|  |- Landing gear
|  |  |- Position*
|  |  |- Mass properties**
|  |  |- Aircraft classification number
|  |  |- Specific
|  |  |  |- Geometry
|  |  |  |  |- Landing gear assembly (ID="0")
|  |  |  |  |  |- Name
|  |  |  |  |  |- Position*
|  |  |  |  |  |- Mass properties**
|  |  |  |  |  |- Assembly components
|  |  |  |  |  |  |- Strut diameter
|  |  |  |  |  |  |- Strut length
|  |  |  |  |  |  |- Tire description (ID="0")
|  |  |  |  |  |  |  |- Name
|  |  |  |  |  |  |  |- Position*
|  |  |  |  |  |  |  |- Tire diameter
|  |  |  |  |  |  |  |- Tire section width
```
<sup>*</sup> Node has been shortened. It contains the following sub-nodes: x, y, z

<sup>*</sup> Node has been shortened. It contains sub-nodes with information on the mass, inertia, and center of gravity.

### Generation of geometry file {#existing-geometry-file}
The calculated geometry data is written to the `existing_landing_gear_geometry.xml` file and can then be used if the `use_existing_geometry` flag is set to `true`.

## Troubleshooting {#troubleshooting}
- The tool does not run properly? *Make sure you have all the paths set up correctly and the specified elements exist.*
